@@ -1,5 +1,6 @@
 from django.conf.urls import *
 
-urlpatterns = patterns('matgendb.webui.home.views',
+urlpatterns = patterns(
+    'matgendb.webui.home.views',
     (r'^$', 'index')
 )
